==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/el/Filter.js <==
({
	"clearFilterDialogTitle": "Εκκαθάριση φίλτρου",
	"filterDefDialogTitle": "Φίλτρο",
	"incompleteRuleTip": "Αυτός ο κανόνας δεν είναι πλήρης.",
	"ruleTitleTemplate": "Κανόνας ${0}",
	
	"conditionEqual": "ίσο",
	"conditionNotEqual": "όχι ίσο",
	"conditionLess": "είναι μικρότερο από",
	"conditionLessEqual": "μικρότερο ή ίσο",
	"conditionLarger": "είναι μεγαλύτερο από",
	"conditionLargerEqual": "μεγαλύτερο ή ίσο",
	"conditionContains": "περιέχει",
	"conditionIs": "είναι",
	"conditionStartsWith": "αρχίζει από",
	"conditionEndWith": "τελειώνει σε",
	"conditionNotContain": "δεν περιέχει",
	"conditionIsNot": "δεν είναι",
	"conditionNotStartWith": "δεν αρχίζει από",
	"conditionNotEndWith": "δεν τελειώνει σε",
	"conditionBefore": "πριν",
	"conditionAfter": "μετά",
	"conditionRange": "εύρος",
	
	"all": "όλα",
	"any": "οποιοδήποτε",
	"relationAll": "όλοι οι κανόνες",
	"waiRelAll": "Αντιστοιχία με όλους τους παρακάτω κανόνες:",
	"relationAny": "οποιοσδήποτε κανόνας",
	"waiRelAny": "Αντιστοιχία με οποιονδήποτε από τους παρακάτω κανόνες:",
	"relationMsgFront": "Αντιστοιχία",
	"relationMsgTail": "",
	"and": "και",
	"or": "ή",
	
	"addRuleButton": "Προσθήκη κανόνα",
	"waiAddRuleButton": "Προσθήκη νέου κανόνα",
	"removeRuleButton": "Αφαίρεση κανόνα",
	"waiRemoveRuleButtonTemplate": "Αφαίρεση κανόνα ${0}",
	
	"cancelButton": "Ακύρωση",
	"waiCancelButton": "Ακύρωση αυτού του πλαισίου διαλόγου",
	"clearButton": "Εκκαθάριση",
	"waiClearButton": "Εκκαθάριση του φίλτρου",
	"filterButton": "Φίλτρο",
	"waiFilterButton": "Υποβολή του φίλτρου",
	
	"columnSelectLabel": "Στήλη",
	"waiColumnSelectTemplate": "Στήλη για τον κανόνα ${0}",
	"conditionSelectLabel": "Συνθήκη",
	"waiConditionSelectTemplate": "Συνθήκη για τον κανόνα ${0}",
	"valueBoxLabel": "Τιμή",
	"waiValueBoxTemplate": "Καταχωρήστε τιμή φίλτρου για τον κανόνα ${0}",
	
	"rangeTo": "έως",
	"rangeTemplate": "από ${0} έως ${1}",
	
	"statusTipHeaderColumn": "Στήλη",
	"statusTipHeaderCondition": "Κανόνες",
	"statusTipTitle": "Γραμμή φίλτρου",
	"statusTipMsg": "Πατήστε στη γραμμή φίλτρου για φιλτράρισμα με βάση τις τιμές στο ${0}.",
	"anycolumn": "οποιαδήποτε στήλη",
	"statusTipTitleNoFilter": "Γραμμή φίλτρου",
	"statusTipTitleHasFilter": "Φίλτρο",
	"statusTipRelPre": "Αντιστοιχία",
	"statusTipRelPost": "κανόνες.",
	
	"defaultItemsName": "στοιχεία",
	"filterBarMsgHasFilterTemplate": "Εμφανίζονται ${0} από ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Δεν έχει εφαρμοστεί φίλτρο",
	
	"filterBarDefButton": "Ορισμός φίλτρου",
	"waiFilterBarDefButton": "Φιλτράρισμα του πίνακα",
	"a11yFilterBarDefButton": "Φιλτράρισμα...",
	"filterBarClearButton": "Εκκαθάριση φίλτρου",
	"waiFilterBarClearButton": "Εκκαθάριση του φίλτρου",
	"closeFilterBarBtn": "Κλείσιμο γραμμής φίλτρου",
	
	"clearFilterMsg": "Με την επιλογή αυτή θα αφαιρεθεί το φίλτρο και θα εμφανιστούν όλες οι διαθέσιμες εγγραφές.",
	"anyColumnOption": "Οποιαδήποτε στήλη",
	
	"trueLabelEditable": "Επιλεγμένο",
	"trueLabel": "Αληθές",
	"falseLabel": "Ψευδές"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/el/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Εκκαθάριση φίλτρου",
	"filterDefDialogTitle": "Φίλτρο",
	"ruleTitleTemplate": "Κανόνας ${0}",
	
	"conditionEqual": "ίσο",
	"conditionNotEqual": "όχι ίσο",
	"conditionLess": "είναι μικρότερο από",
	"conditionLessEqual": "μικρότερο ή ίσο",
	"conditionLarger": "είναι μεγαλύτερο από",
	"conditionLargerEqual": "μεγαλύτερο ή ίσο",
	"conditionContains": "περιέχει",
	"conditionIs": "είναι",
	"conditionStartsWith": "αρχίζει από",
	"conditionEndWith": "τελειώνει σε",
	"conditionNotContain": "δεν περιέχει",
	"conditionIsNot": "δεν είναι",
	"conditionNotStartWith": "δεν αρχίζει από",
	"conditionNotEndWith": "δεν τελειώνει σε",
	"conditionBefore": "πριν",
	"conditionAfter": "μετά",
	"conditionRange": "εύρος",
	"conditionIsEmpty": "είναι κενό",
	
	"all": "όλα",
	"any": "οποιοδήποτε",
	"relationAll": "όλοι οι κανόνες",
	"waiRelAll": "Αντιστοιχία με όλους τους παρακάτω κανόνες:",
	"relationAny": "οποιοσδήποτε κανόνας",
	"waiRelAny": "Αντιστοιχία με οποιονδήποτε από τους παρακάτω κανόνες:",
	"relationMsgFront": "Αντιστοιχία",
	"relationMsgTail": "",
	"and": "και",
	"or": "ή",
	
	"addRuleButton": "Προσθήκη κανόνα",
	"waiAddRuleButton": "Προσθήκη νέου κανόνα",
	"removeRuleButton": "Αφαίρεση κανόνα",
	"waiRemoveRuleButtonTemplate": "Αφαίρεση κανόνα ${0}",
	
	"cancelButton": "Ακύρωση",
	"waiCancelButton": "Ακύρωση αυτού του πλαισίου διαλόγου",
	"clearButton": "Εκκαθάριση",
	"waiClearButton": "Εκκαθάριση του φίλτρου",
	"filterButton": "Φίλτρο",
	"waiFilterButton": "Υποβολή του φίλτρου",
	
	"columnSelectLabel": "Στήλη",
	"waiColumnSelectTemplate": "Στήλη για τον κανόνα ${0}",
	"conditionSelectLabel": "Συνθήκη",
	"waiConditionSelectTemplate": "Συνθήκη για τον κανόνα ${0}",
	"valueBoxLabel": "Τιμή",
	"waiValueBoxTemplate": "Καταχωρήστε τιμή φίλτρου για τον κανόνα ${0}",
	
	"rangeTo": "έως",
	"rangeTemplate": "από ${0} έως ${1}",
	
	"statusTipHeaderColumn": "Στήλη",
	"statusTipHeaderCondition": "Κανόνες",
	"statusTipTitle": "Γραμμή φίλτρου",
	"statusTipMsg": "Πατήστε στη γραμμή φίλτρου για φιλτράρισμα με βάση τις τιμές στο ${0}.",
	"anycolumn": "οποιαδήποτε στήλη",
	"statusTipTitleNoFilter": "Γραμμή φίλτρου",
	"statusTipTitleHasFilter": "Φίλτρο",
	"statusTipRelAny": "Αντιστοιχία με οποιουσδήποτε κανόνες.",
	"statusTipRelAll": "Αντιστοιχία με όλους τους κανόνες.",
	
	"defaultItemsName": "στοιχεία",
	"filterBarMsgHasFilterTemplate": "Εμφανίζονται ${0} από ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Δεν έχει εφαρμοστεί φίλτρο",
	
	"filterBarDefButton": "Ορισμός φίλτρου",
	"waiFilterBarDefButton": "Φιλτράρισμα του πίνακα",
	"a11yFilterBarDefButton": "Φιλτράρισμα...",
	"filterBarClearButton": "Εκκαθάριση φίλτρου",
	"waiFilterBarClearButton": "Εκκαθάριση του φίλτρου",
	"closeFilterBarBtn": "Κλείσιμο γραμμής φίλτρου",
	
	"clearFilterMsg": "Με την επιλογή αυτή θα αφαιρεθεί το φίλτρο και θα εμφανιστούν όλες οι διαθέσιμες εγγραφές.",
	"anyColumnOption": "Οποιαδήποτε στήλη",
	
	"trueLabel": "Αληθές",
	"falseLabel": "Ψευδές"
})
//end v1.x content
);
